[git commit] syslogd: small fix to config patch

Denys Vlasenko vda.linux at googlemail.com
Sat Apr 16 17:36:15 UTC 2011


commit: http://git.busybox.net/busybox/commit/?id=e9c8bed4d3b157097e89ee2611ca731e37ce8d7d
branch: http://git.busybox.net/busybox/commit/?id=refs/heads/master

Signed-off-by: Sergey Naumov <sknaumov at gmail.com>
Signed-off-by: Denys Vlasenko <vda.linux at googlemail.com>
---
 sysklogd/syslogd.c |   12 +++++++++---
 1 files changed, 9 insertions(+), 3 deletions(-)

diff --git a/sysklogd/syslogd.c b/sysklogd/syslogd.c
index 7ddd3e4..0799038 100644
--- a/sysklogd/syslogd.c
+++ b/sysklogd/syslogd.c
@@ -385,9 +385,15 @@ static void parse_syslogdcfg(const char *file)
 			cur_selector = next_selector;
 		} while (cur_selector);
 
-		/* check whether current file name was mentioned in previous rules.
-		 * temporarily use cur_rule as iterator, but *pp_rule still points to
-		 * currently processing rule entry.
+		/* check whether current file name was mentioned in previous rules or
+		 * as global logfile (G.logFile).
+		 */
+		if (strcmp(G.logFile.path, tok[1]) == 0) {
+			cur_rule->file = &G.logFile;
+			goto found;
+		}
+		/* temporarily use cur_rule as iterator, but *pp_rule still points
+		 * to currently processing rule entry.
 		 * NOTE: *pp_rule points to the current (and last in the list) rule.
 		 */
 		for (cur_rule = G.log_rules; cur_rule != *pp_rule; cur_rule = cur_rule->next) {
-- 
1.7.3.4



More information about the busybox-cvs mailing list